@@ -1,6 +1,7 @@
 /*
     netutl.h -- header file for netutl.c
-    Copyright (C) 1998,99 Ivo Timmermans <zarq@iname.com>
+    Copyright (C) 1998-2003 Ivo Timmermans <zarq@iname.com>
+                  2000-2003 Guus Sliepen <guus@sliepen.eu.org>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,6 +16,8 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+    $Id: netutl.h,v 1.2.4.18 2003/07/24 12:08:15 guus Exp $
 */
 
 #ifndef __TINC_NETUTL_H__
@@ -22,14 +25,17 @@
 
 #include "net.h"
 
-extern conn_list_t *lookup_conn(ip_t);
-extern void free_conn_element(conn_list_t *);
-extern void free_conn_list(conn_list_t*);
-extern void prune_conn_list(void);
-extern conn_list_t *new_conn_list(void);
-extern void destroy_conn_list(void);
-extern char *hostlookup(unsigned long);
-extern ip_mask_t *strtoip(char*);
-extern void dump_conn_list(void);
+extern bool hostnames;
 
-#endif /* __TINC_NETUTL_H__ */
+extern struct addrinfo *str2addrinfo(const char *, const char *, int);
+extern sockaddr_t str2sockaddr(const char *, const char *);
+extern void sockaddr2str(const sockaddr_t *, char **, char **);
+extern char *sockaddr2hostname(const sockaddr_t *);
+extern int sockaddrcmp(const sockaddr_t *, const sockaddr_t *);
+extern void sockaddrunmap(sockaddr_t *);
+extern int maskcmp(const void *, const void *, int, int);
+extern void maskcpy(void *, const void *, int, int);
+extern void mask(void *, int, int);
+extern bool maskcheck(const void *, int, int);
+
+#endif							/* __TINC_NETUTL_H__ */
